.TH XSF3 1L "26 April 1994"
.SH NAME
xsf3 \- a preprocessor and compiler interface for
the structured Fortran language SFTRAN3
.SH SYNOPSIS
.B xsf3
\fB[-C] [-D] [-E] [-H] [-I:\fP\fInum\fP\fB] [-K]
[-L] [-M:\fP\fInum\fP\fB] [-N] [-P] [-Q] [-R] [-V]
[-W:\fP\fInum\fP] [compiler and loader options]
\fIfile1\fP [\fIfile2 file3 .\|.\|.\fP]
.SH DESCRIPTION
.I xsf3
assumes that the files
.I file*.sf3
contain code written in SFTRAN3, a structured
Fortran language.  Fortran code is produced and
placed in corresponding files
.IR file*.f .
Log files are placed in
.IR file*.sfl .
.PP
File dates and times are compared to determine
whether to preprocess the files
.I file*.sf3
or simply to run the Fortran compiler (this action
may be overriden by the
.B \-R
option).
.PP
The global variables SF3FLAGS and FFLAGS may be
used to provide switches for
.I sf3
and the Fortran compiler as used inside
.IR xsf3 .
In addition, if the file
.I sf3.opt
exists in the current or HOME directory, its
contents will be appended to the command line.
Since options are scanned from left to right,
SF3FLAGS values will override any provided in the
.I sf3.opt
file.
.PP
Options may also be specified in the file
.I ./xsf3rc
in the current directory, or if not found there,
in the login directory.
.PP
If both an initialization file and an environment
variable are specified, the environment variable
switches will be presented
to
.I sf3
first, overriding the same switches from the
startup file.  Similarly, command line switches
override ones from both of these sources.
.PP
This program is distributed with the <PLOT79>
system.
.SH OPTIONS
All unrecognized options are passed through
verbatim to the Fortran compiler which may in turn
send them to the linker.  To minimize conflict
with native compiler options, all options handled
by
.I xsf3
are written with upper-case letters.
.PP
If a native Fortran compiler option does conflict
with one of the above, it must be supplied inside
a quoted string argument with a leading backslash
or a leading brace pair.  E.g.
.I "{}-N"
and
.I "\-N"
will be passed to Fortran as
.IR \-N ,
instead of to
.IR sf3 .
.TP
.B \-C
Produce CDC-style code for READ/WRITE END and ERR
parameters.
.TP
.B \-D
Debug; embed SFTRAN3 code as comments in Fortran
code output.
.TP
.B \-E
Run the SFTRAN3 preprocessor, but do not invoke
the Fortran compiler or linker.
.TP
.B \-H
Display a help file and terminate immediately.
.TP
.BI \-I: num
Set structure indentation to
.I num
(0 to 9).
.TP
.B \-K
Keep
.I *.f
files after a successful compilation.  By default,
they are deleted.  If compilation fails, they are
still preserved.
.TP
.B \-L
Set the LINEUP option which connects structure
begin/end with dotted lines in the
.I *.sfl
files.
.TP
.BI \-M: num
Set maximum lines per page to
.I num
(suggested: 58 for 6 lpi and
80 for 8 lpi); ignored when prettyprinting.
.TP
.B \-N
Inhibit production of
.I *.sfl
files.
.TP
.B \-P
Prettyprinted source code sent to
.I *.sfl
files instead of a
normal listing.
.TP
.B \-Q
Quick mode; suppress reading of
.I .xsf3rc
files.
.TP
.B \-R
Reprocess everything, even if
.I *.f
or
.I *.o
files are newer than
.I .sf3
files.
.TP
.B \-V
Verbose mode; display generated commands before executing them.
.TP
.BI \-W: num
Set
.I *.sfl
file line width to
.I num
(72 to 120).
.SH EXAMPLES
The following would take the files form the
current directory matching the patterns
.I a*.sf3
and
.IR *bar*.sf3 ,
produce Fortran code files, invoke the Fortran
compiler to produce object files, produce log
files of 72 column width, and retain the Fortran
files.
.br
xsf3\ \ \-W:72\ \ \-K\ \ \ a*.sf3\ \ *bar*.sf3
.PP
To preprocess, compile, and link a single complete
program in the file
.IR foo.sf3 ,
this command suffices:
.br
xsf3 \-o foo foo.sf3
.PP
To preprocess and compile without linking:
.br
xsf3 \-c foo.sf3
.PP
To preprocess only:
.br
xsf3 \-E foo.sf3
.SH FILES
.TP 2.5i
.I /usr/local/plot79/sf3dir/*
files required to make
.I sf3
(includes executable file)
.TP
.I /usr/local/plot79/sf3
shell script
.TP
.I /usr/local/plot79/xsf3
shell script
.TP
.I ${HOME}/.xsf3rc
customization file
.TP
.I ./.xsf3rc
customization file
.SH "SEE ALSO"
sf3 (1L)
.LP
.IR "SFTRAN/3 Installation Guide" .
Nelson H. F. Beebe.  1980.
.br
.I SFTRAN3 Programmer's Reference Manual
(Jet Propulsion Laboratory
Document no. 1846-98, Dec. 1, 1978).
.SH AUTHOR
Nelson H. F. Beebe, Ph.D.
.br
Center for Scientific Computing
.br
Department of Mathematics
.br
University of Utah
.br
Salt Lake City, UT 84112
.br
USA
.br
Tel: +1 801 581 5254
.br
FAX: +1 801 581 4148
